@@ -7,7 +7,11 @@ from typing import Any, Callable
 
 import sys
 
-from .backend import HooksBackend, get_hooks_backend, python_object_backend_factory
+from pyhashxx import hashxx
+
+from .backends.backend_state import get_hooks_backend
+from .backends.interface import HooksBackend
+from .backends.python_objects_backend import python_object_backend_factory
 from .scope import HOOKED_FUNCTION_ATTRIBUTE, _hook_scope_manager
 
 SPECIAL_HOOKS = ["create_context"]
@@ -97,10 +101,9 @@ def __identify_hook_and_backend(
     ) and frame.f_code.co_name not in SPECIAL_HOOKS:
         # We add a prefix to the identifier to ensure that the identifier is unique and that we can use hooks inside
         # hooks
-        if not frame.f_globals["__name__"].startswith("hooks."):
-            identifier_prefix += __frame_parts_to_identifier(
-                frame.f_code.co_filename, frame.f_lineno, frame.f_code.co_name
-            )
+        identifier_prefix += __frame_parts_to_identifier(
+            frame.f_code.co_filename, frame.f_lineno, frame.f_code.co_name
+        )
         frame = frame.f_back
 
     frame_identifier = identifier_prefix + __frame_parts_to_identifier(
@@ -133,11 +136,11 @@ def __identify_hook_and_backend(
     if (not is_method and not is_class_method) or always_global_backend:
         _backend = get_hooks_backend()
         return (
-            f"{prefix}{frame_identifier}",
+            str(hashxx(f"{prefix}{frame_identifier}".encode())),
             _backend,
         )
 
     return (
-        f"{prefix}{frame_identifier}{frame.f_code.co_name}",
+        str(hashxx(f"{prefix}{frame_identifier}{frame.f_code.co_name}".encode())),
         python_object_backend_factory(owner),
     )
